@@ -27,25 +27,16 @@
 #include "yelp-bookmarks.h"
 #include "yelp-utils.h"
 #include "yelp-window.h"
+#include "yelp-debug.h"
 
 #include <string.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtktreemodel.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <glade/glade.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 #include <libxml/xmlwriter.h>
-#include <libgnome/gnome-config.h>
-
-#ifdef YELP_DEBUG
-#define d(x) x
-#else
-#define d(x)
-#endif
 
 #define COL_NAME   0
 #define COL_LABEL  1
@@ -53,10 +44,11 @@
 #define COL_HEADER 3
 #define TOC_PATH "ui/menubar/BookmarksMenu/BookmarksTOC"
 #define DOC_PATH "ui/menubar/BookmarksMenu/BookmarksDOC"
-#define BK_CONFIG_WIDTH  "/yelp/Bookmarks/width"
-#define BK_CONFIG_HEIGHT "/yelp/Bookmarks/height"
-#define BK_CONFIG_WIDTH_DEFAULT  "360"
-#define BK_CONFIG_HEIGHT_DEFAULT "360"
+#define BK_CONFIG_BK_GROUP "Bookmarks"
+#define BK_CONFIG_WIDTH  "width"
+#define BK_CONFIG_HEIGHT "height"
+#define BK_CONFIG_WIDTH_DEFAULT  360
+#define BK_CONFIG_HEIGHT_DEFAULT 360
 
 static GSList *windows;
 static GtkTreeStore *actions_store;
@@ -144,7 +136,7 @@ static void      bookmarks_menu_open_cb     (GtkAction           *action,
 					     GtkWidget           *widget);
 static gboolean  bookmarks_button_press_cb  (GtkWidget           *widget,
 					     GdkEventButton      *event);
-static gboolean  bookmarks_configure_cb     (GtkWidget           *widget, 
+static gboolean  bookmarks_configure_cb     (GtkWidget           *widget,
 					     GdkEventConfigure   *event,
 					     gpointer             data);
 static void      selection_changed_cb       (GtkTreeSelection    *selection,
@@ -169,8 +161,8 @@ static const GtkActionEntry popup_entries[] = {
 void
 yelp_bookmarks_init (void)
 {
-    gboolean read = FALSE;
     gchar   *filename = NULL;
+    const gchar *override;
 
     windows = NULL;
     actions_store = gtk_tree_store_new (4,
@@ -179,11 +171,16 @@ yelp_bookmarks_init (void)
 					G_TYPE_BOOLEAN,
 					G_TYPE_BOOLEAN);
 
-    filename = g_build_filename (g_get_home_dir (), ".gnome2",
-				 "yelp-bookmarks.xbel", NULL);
+    override = g_getenv ("GNOME22_USER_DIR");
+
+    if (override)
+        filename = g_build_filename (override, "yelp-bookmarks.xbel", NULL);
+    else
+        filename = g_build_filename (g_get_home_dir (), ".gnome2",
+				     "yelp-bookmarks.xbel", NULL);
 
     if (g_file_test (filename, G_FILE_TEST_EXISTS))
-	read = bookmarks_read (filename);
+	bookmarks_read (filename);
 
     g_free (filename);
 }
@@ -261,10 +258,10 @@ bookmarks_ensure_valid (void)
 					    &doc_iter)) {
 	    gtk_tree_store_remove (actions_store, &doc_iter);
 	    have_doc = FALSE;
-	}	
+	}
 }
 
-static gboolean 
+static gboolean
 bookmarks_dup_finder (GtkTreeModel *model, GtkTreePath *path,
 		      GtkTreeIter *iter, gpointer data)
 {
@@ -291,7 +288,8 @@ bookmarks_dup_finder (GtkTreeModel *model, GtkTreePath *path,
 void
 yelp_bookmarks_add (const gchar *uri, YelpWindow *window)
 {
-    GladeXML    *glade;
+    GtkBuilder  *builder;
+    GError      *error = NULL;
     GtkWidget   *dialog;
     GtkEntry    *entry;
     gchar       *title;
@@ -299,39 +297,50 @@ yelp_bookmarks_add (const gchar *uri, YelpWindow *window)
 
     title = (gchar *) gtk_window_get_title (GTK_WINDOW (window));
     dup_uri = g_strdup (uri);
-    
+
     if (dup_title)
 	g_free (dup_title);
     dup_title = NULL;
     gtk_tree_model_foreach (GTK_TREE_MODEL (actions_store),
 			    bookmarks_dup_finder, dup_uri);
     if (dup_title) {
-	GtkWidget *dialog;
+	char *escaped_title, *markup;
+
 	dialog = gtk_message_dialog_new_with_markup
 	    (GTK_WINDOW (window),
 	     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 	     GTK_MESSAGE_INFO,
 	     GTK_BUTTONS_OK,
-	     _("A bookmark titled <b>%s</b> already exists for this page."),
-	     dup_title);
+	     NULL);
+
+	escaped_title = g_markup_printf_escaped
+		("<b>%s</b>", dup_title);
+	markup = g_strdup_printf
+		(_("A bookmark titled %s already exists for this page."),
+		escaped_title);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
+	g_free (markup);
+	g_free (escaped_title);
+
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
+
 	g_free (dup_title);
 	dup_title = NULL;
 	return;
     }
 
-    glade = glade_xml_new (DATADIR "/yelp/ui/yelp.glade",
-			   "add_bookmark_dialog",
-			   NULL);
-    if (!glade) {
-	g_warning ("Could not find necessary glade file "
-		   DATADIR "/yelp/ui/yelp.glade");
-	return;
+    builder = gtk_builder_new ();
+    if (!gtk_builder_add_from_file (builder,
+                                    DATADIR "/yelp/ui/yelp-bookmarks-add.ui",
+                                    &error)) {
+        g_warning ("Could not load builder file: %s", error->message);
+        g_error_free(error);
+        return;
     }
 
-    dialog = glade_xml_get_widget (glade, "add_bookmark_dialog");
-    entry = GTK_ENTRY (glade_xml_get_widget (glade, "bookmark_title_entry"));
+    dialog = GTK_WIDGET (gtk_builder_get_object (builder, "add_bookmark_dialog"));
+    entry = GTK_ENTRY (gtk_builder_get_object (builder, "bookmark_title_entry"));
     gtk_entry_set_text (entry, title);
     gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
 
@@ -342,7 +351,6 @@ yelp_bookmarks_add (const gchar *uri, YelpWindow *window)
 		      G_CALLBACK (bookmark_add_response_cb),
 		      dup_uri);
 
-    g_object_unref (glade);
     gtk_window_present (GTK_WINDOW (dialog));
 }
 
@@ -434,7 +442,7 @@ bookmarks_add_bookmark (const gchar  *uri,
 			-1);
     if (save) {
 	for (cur = windows; cur != NULL; cur = cur->next) {
-	    window_add_bookmark ((YelpWindowData *) cur->data, (gchar *) uri, 
+	    window_add_bookmark ((YelpWindowData *) cur->data, (gchar *) uri,
 				 title);
 	}
 	yelp_bookmarks_write ();
@@ -481,7 +489,7 @@ bookmarks_rebuild_menus (void)
 	window_remove_bookmark_menu ((YelpWindowData *) cur->data);
     }
 
-    top_valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (actions_store), 
+    top_valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (actions_store),
 					       &top_iter);
     while (top_valid) {
 	if (gtk_tree_model_iter_has_child (GTK_TREE_MODEL (actions_store),
@@ -501,11 +509,11 @@ bookmarks_rebuild_menus (void)
 		g_free (name);
 		g_free (label);
 
-		sub_valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (actions_store), 
+		sub_valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (actions_store),
 						      &sub_iter);
 	    }
 	}
-	top_valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (actions_store), 
+	top_valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (actions_store),
 					      &top_iter);
     }
 
@@ -522,13 +530,13 @@ bookmarks_key_event_cb (GtkWidget   *widget,
     GtkTreeSelection *sel;
     GtkTreeModel *model;
     GtkTreeIter iter;
-    
+
     model = gtk_tree_view_get_model (view);
     sel = gtk_tree_view_get_selection (view);
-    
+
     if (gtk_tree_selection_get_selected (sel, &model, &iter)) {
 	path = gtk_tree_model_get_path (model, &iter);
-	
+
 	switch (event->keyval) {
 	case GDK_BackSpace:
 	case GDK_Delete:
@@ -573,10 +581,10 @@ bookmarks_open_cb (GtkTreeView *view, GtkTreePath *path,
 	gtk_tree_model_get (GTK_TREE_MODEL (actions_store), &iter,
 			    COL_NAME, &name,
 			    COL_LABEL, &title, -1);
-	
+
 	cur = windows;
 	data = cur->data;
-	
+
 	g_signal_emit_by_name (data->window, "new_window_requested", name, NULL);
     }
 }
@@ -600,38 +608,69 @@ bookmarks_cell_edited_cb (GtkCellRendererText *cell, const gchar *path_string,
 void
 yelp_bookmarks_edit (void)
 {
-    GladeXML    *glade;
+    GtkBuilder *builder;
+    GError *error = NULL;
     GtkTreeView *view;
     GtkTreeSelection *select;
     GtkCellRenderer *renderer;
     gint width, height;
-    
+    GKeyFile *keyfile;
+    GError *config_error = NULL;
+    gchar *config_path;
+    const gchar *override;
+
     if (!bookmarks_dialog) {
-	glade = glade_xml_new (DATADIR "/yelp/ui/yelp.glade",
-			       "bookmarks_dialog",
-			       NULL);
-	if (!glade) {
-	    g_warning ("Could not find necessary glade file "
-		       DATADIR "/yelp/ui/yelp.glade");
-	    return;
+        builder = gtk_builder_new ();
+        if (!gtk_builder_add_from_file (builder,
+                                        DATADIR "/yelp/ui/yelp-bookmarks.ui",
+                                        &error)) {
+            g_warning ("Could not load builder file: %s", error->message);
+            g_error_free(error);
+            return;
+        }
+
+        bookmarks_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "bookmarks_dialog"));
+	view = GTK_TREE_VIEW (gtk_builder_get_object (builder, "bookmarks_view"));
+ 	keyfile = g_key_file_new();
+        override = g_getenv ("GNOME22_USER_DIR");
+        if (override)
+            config_path = g_build_filename (override, "yelp", NULL);
+        else
+            config_path = g_build_filename (g_get_home_dir(),
+                                            ".gnome2", "yelp", NULL);
+
+ 	if( !g_key_file_load_from_file (keyfile, config_path,
+					G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS,
+					&config_error) ) {
+	    g_warning ("Failed to load config file: %s\n", config_error->message);
+	    g_error_free (config_error);
+
+	    width = BK_CONFIG_WIDTH_DEFAULT;
+	    height = BK_CONFIG_HEIGHT_DEFAULT;
+	} else {
+	    width = g_key_file_get_integer (keyfile, BK_CONFIG_BK_GROUP,
+					    BK_CONFIG_WIDTH, NULL);
+	    height = g_key_file_get_integer (keyfile, BK_CONFIG_BK_GROUP,
+					     BK_CONFIG_HEIGHT, NULL);
+
+	    if (width == 0)
+		width = BK_CONFIG_WIDTH_DEFAULT;
+	    if (height == 0)
+		height = BK_CONFIG_HEIGHT_DEFAULT;
 	}
 
-	bookmarks_dialog = glade_xml_get_widget (glade, "bookmarks_dialog");
-	view = GTK_TREE_VIEW (glade_xml_get_widget (glade, "bookmarks_view"));
-	width = gnome_config_get_int (BK_CONFIG_WIDTH
-				      "=" BK_CONFIG_WIDTH_DEFAULT);
-	height = gnome_config_get_int (BK_CONFIG_HEIGHT
-				       "=" BK_CONFIG_HEIGHT_DEFAULT);
-	gtk_window_set_default_size (GTK_WINDOW (bookmarks_dialog), 
+ 	g_free (config_path);
+ 	g_key_file_free (keyfile);
+	gtk_window_set_default_size (GTK_WINDOW (bookmarks_dialog),
 				     width, height);
 
 	g_signal_connect (G_OBJECT (bookmarks_dialog), "response",
 			  G_CALLBACK (gtk_widget_hide), NULL);
 	g_signal_connect (G_OBJECT (bookmarks_dialog), "delete_event",
 			  G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-	
+
 	renderer = gtk_cell_renderer_text_new ();
-    
+
 	gtk_tree_view_insert_column_with_attributes
 	    (view, -1,
 	     NULL, renderer,
@@ -641,28 +680,28 @@ yelp_bookmarks_edit (void)
 	gtk_tree_view_set_model (view, GTK_TREE_MODEL (actions_store));
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
-	
+
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
 	gtk_tree_view_expand_all (GTK_TREE_VIEW (view));
 
 	g_signal_connect (G_OBJECT (view), "row-activated",
 			  G_CALLBACK (bookmarks_open_cb),
-			  NULL); 
+			  NULL);
 	g_signal_connect (G_OBJECT (view), "key-press-event",
 			  G_CALLBACK (bookmarks_key_event_cb),
 			  NULL);
 	g_signal_connect (G_OBJECT (renderer), "edited",
 			  G_CALLBACK (bookmarks_cell_edited_cb), NULL);
 
-	edit_open_button = glade_xml_get_widget (glade, "open_button");
+	edit_open_button = GTK_WIDGET (gtk_builder_get_object (builder, "open_button"));
 	g_signal_connect (G_OBJECT (edit_open_button), "clicked",
 			  G_CALLBACK (bookmarks_open_button_cb),
 			  view);
-	edit_rename_button = glade_xml_get_widget (glade, "rename_button");
+	edit_rename_button = GTK_WIDGET (gtk_builder_get_object (builder, "rename_button"));
 	g_signal_connect (G_OBJECT (edit_rename_button), "clicked",
 			  G_CALLBACK (bookmarks_rename_button_cb),
 			  view);
-	edit_remove_button = glade_xml_get_widget (glade, "remove_button");
+	edit_remove_button = GTK_WIDGET (gtk_builder_get_object (builder, "remove_button"));
 	g_signal_connect (G_OBJECT (edit_remove_button), "clicked",
 			  G_CALLBACK (bookmarks_remove_button_cb),
 			  view);
@@ -675,8 +714,6 @@ yelp_bookmarks_edit (void)
 	g_signal_connect (G_OBJECT (bookmarks_dialog), "configure-event",
 			  G_CALLBACK (bookmarks_configure_cb),
 			  NULL);
-
-	g_object_unref (glade);
     }
 
     gtk_window_present (GTK_WINDOW (bookmarks_dialog));
@@ -687,10 +724,38 @@ bookmarks_configure_cb (GtkWidget *widget, GdkEventConfigure *event,
 			gpointer data)
 {
     gint width, height;
+    GKeyFile *keyfile;
+    gchar *config_path, *sdata;
+    GError *config_error = NULL;
+    gsize config_size;
+    const gchar *override;
+
     gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
-    gnome_config_set_int (BK_CONFIG_WIDTH, width);
-    gnome_config_set_int (BK_CONFIG_HEIGHT, height);
-    gnome_config_sync ();
+
+    keyfile = g_key_file_new ();
+    override = g_getenv ("GNOME22_USER_DIR");
+    if (override)
+        config_path = g_build_filename (override, "yelp", NULL);
+    else
+        config_path = g_build_filename (g_get_home_dir (),
+                                        ".gnome2", "yelp", NULL);
+
+    g_key_file_set_integer (keyfile, BK_CONFIG_BK_GROUP,
+			    BK_CONFIG_WIDTH, width);
+    g_key_file_set_integer (keyfile, BK_CONFIG_BK_GROUP,
+			    BK_CONFIG_HEIGHT, height);
+
+    sdata = g_key_file_to_data (keyfile, &config_size, NULL);
+
+    if ( !g_file_set_contents (config_path, sdata, config_size,
+			       &config_error) ) {
+	g_warning ("Failed to save config file: %s\n", config_error->message);
+	g_error_free (config_error);
+    }
+
+    g_free (sdata);
+    g_free (config_path);
+    g_key_file_free (keyfile);
 
     return FALSE;
 }
@@ -700,7 +765,7 @@ selection_changed_cb (GtkTreeSelection *selection, gpointer data)
 {
     GtkTreeIter iter;
     if (gtk_tree_selection_get_selected (selection, NULL, &iter) &&
-	!gtk_tree_model_iter_has_child (GTK_TREE_MODEL (actions_store), 
+	!gtk_tree_model_iter_has_child (GTK_TREE_MODEL (actions_store),
 					&iter)) {
 	/*A row is highlighted - sensitise the various widgets*/
 	gtk_widget_set_sensitive (GTK_WIDGET (edit_open_button), TRUE);
@@ -712,7 +777,7 @@ selection_changed_cb (GtkTreeSelection *selection, gpointer data)
 	gtk_widget_set_sensitive (GTK_WIDGET (edit_open_button), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (edit_rename_button), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (edit_remove_button), FALSE);
-	
+
     }
 }
 
@@ -730,9 +795,9 @@ bookmarks_open_button_cb (GtkWidget *widget, GtkTreeView *view)
     select = gtk_tree_view_get_selection (view);
     if (gtk_tree_selection_get_selected (select, NULL, &iter)) {
 	path = gtk_tree_model_get_path (model, &iter);
-	
+
 	bookmarks_open_cb (view, path, NULL, NULL);
-	
+
 	gtk_tree_path_free (path);
     }
 }
@@ -752,7 +817,7 @@ bookmarks_rename_button_cb (GtkWidget *widget, GtkTreeView *view)
     if (selection) {
 	path = gtk_tree_model_get_path (model, &iter);
 	col = gtk_tree_view_get_column (view, 0);
-	
+
 	gtk_tree_view_set_cursor (view, path, col, TRUE);
     }
 }
@@ -824,7 +889,7 @@ bookmarks_menu_edit_cb (GtkAction *action, GtkWidget *widget)
     if (gtk_tree_selection_get_selected (sel, &model, &iter)) {
 	path = gtk_tree_model_get_path (model, &iter);
 	col = gtk_tree_view_get_column (view, 0);
-	
+
 	gtk_tree_view_set_cursor (view, path, col, TRUE);
     }
 }
@@ -838,7 +903,7 @@ bookmarks_menu_remove_cb (GtkAction *action, GtkWidget *widget)
 
     sel = gtk_tree_view_get_selection (view);
     if (gtk_tree_selection_get_selected (sel, NULL, &iter)) {
-	
+
 	gtk_tree_store_remove (actions_store, &iter);
 	bookmarks_ensure_valid ();
 	bookmarks_rebuild_menus ();
@@ -856,7 +921,7 @@ bookmarks_menu_open_cb (GtkAction *action, GtkWidget *widget)
 
     if (gtk_tree_selection_get_selected (sel, &model, &iter)) {
 	path = gtk_tree_model_get_path (model, &iter);
-	
+
 	bookmarks_open_cb (view, path, NULL, NULL);
     }
 }
@@ -891,29 +956,34 @@ void
 yelp_bookmarks_write (void)
 {
     xmlTextWriterPtr file;
-    gint rc;
     GtkTreeIter top_iter, sub_iter;
     gboolean top_valid, sub_valid;
     gchar *filename;
+    const gchar *override;
 
-    filename = g_build_filename (g_get_home_dir (), ".gnome2", 
-				 "yelp-bookmarks.xbel", NULL);
+    override = g_getenv ("GNOME22_USER_DIR");
 
-    file = xmlNewTextWriterFilename (filename, 
+    if (override)
+        filename = g_build_filename (override, "yelp-bookmarks.xbel", NULL);
+    else
+        filename = g_build_filename (g_get_home_dir (), ".gnome2",
+				     "yelp-bookmarks.xbel", NULL);
+
+    file = xmlNewTextWriterFilename (filename,
 				     0);
     if(!file) {
 	g_warning ("Could not create bookmark file %s", filename);
 	return;
     }
 
-    rc = xmlTextWriterStartDocument (file, NULL, NULL, NULL);
-    rc = xmlTextWriterStartElement (file, BAD_CAST "xbel");
-    rc = xmlTextWriterWriteAttribute(file, BAD_CAST "version",
+    xmlTextWriterStartDocument (file, NULL, NULL, NULL);
+    xmlTextWriterStartElement (file, BAD_CAST "xbel");
+    xmlTextWriterWriteAttribute(file, BAD_CAST "version",
                                      BAD_CAST "1.0");
 
-    rc = xmlTextWriterStartElement (file, BAD_CAST "info");
-    rc = xmlTextWriterStartElement (file, BAD_CAST "metadata");
-    rc = xmlTextWriterWriteAttribute(file, BAD_CAST "owner",
+    xmlTextWriterStartElement (file, BAD_CAST "info");
+    xmlTextWriterStartElement (file, BAD_CAST "metadata");
+    xmlTextWriterWriteAttribute(file, BAD_CAST "owner",
                                      BAD_CAST "http://live.gnome.org/Yelp");
     xmlTextWriterEndElement (file);
     xmlTextWriterEndElement (file);
@@ -930,20 +1000,20 @@ yelp_bookmarks_write (void)
 		gchar *name;
 		gchar *label;
 		gtk_tree_model_get (GTK_TREE_MODEL (actions_store), &sub_iter,
-				    COL_NAME, &name, 
+				    COL_NAME, &name,
 				    COL_LABEL, &label,
 				    -1);
 		xmlTextWriterStartElement (file, BAD_CAST "bookmark");
- 		xmlTextWriterWriteAttribute (file, BAD_CAST "href", 
+ 		xmlTextWriterWriteAttribute (file, BAD_CAST "href",
 					     BAD_CAST name);
 
-		rc = xmlTextWriterWriteElement (file,
-						BAD_CAST "title",
-						BAD_CAST label);
+		xmlTextWriterWriteElement (file,
+					   BAD_CAST "title",
+					   BAD_CAST label);
 
-		rc = xmlTextWriterStartElement (file, BAD_CAST "info");
-		rc = xmlTextWriterStartElement (file, BAD_CAST "metadata");
-		rc = xmlTextWriterWriteAttribute
+		xmlTextWriterStartElement (file, BAD_CAST "info");
+		xmlTextWriterStartElement (file, BAD_CAST "metadata");
+		xmlTextWriterWriteAttribute
 		    (file, BAD_CAST "owner",
 		     BAD_CAST "http://live.gnome.org/Yelp");
 		xmlTextWriterEndElement (file); /* metadata */
@@ -961,7 +1031,7 @@ yelp_bookmarks_write (void)
 					      &top_iter);
     }
 
-    rc = xmlTextWriterEndDocument(file);
+    xmlTextWriterEndDocument(file);
     xmlFreeTextWriter(file);
     g_free (filename);
     return;
@@ -999,20 +1069,20 @@ bookmarks_read (const gchar *filename)
 	if (uri) {
 	    xmlXPathObjectPtr title_obj;
 	    xpath->node = node;
-	    title_obj = xmlXPathEvalExpression (BAD_CAST "string(title[1])", 
+	    title_obj = xmlXPathEvalExpression (BAD_CAST "string(title[1])",
 						xpath);
 	    xpath->node = NULL;
 
 	    if (title_obj->stringval)
-		bookmarks_add_bookmark ((const gchar *) uri, 
-					(const gchar *) title_obj->stringval, 
+		bookmarks_add_bookmark ((const gchar *) uri,
+					(const gchar *) title_obj->stringval,
 					FALSE);
 
 	    xmlXPathFreeObject (title_obj);
 	    xmlFree (uri);
 	}
     }
-    
+
     if (obj)
 	xmlXPathFreeObject (obj);
     if (xpath)
